@@ -9,16 +9,23 @@ use Encode ();
 use MIME::Lite;
 use MIME::EncWords ();
 
-use constant TEST    => $ENV{MOJO_MAIL_TEST} || 0;
-use constant CHARSET => 'UTF-8';
+use constant TEST     => $ENV{MOJO_MAIL_TEST} || 0;
+use constant FROM     => 'test-mail-plugin@mojolicio.us';
+use constant CHARSET  => 'UTF-8';
+use constant ENCODING => 'base64';
 
-our $VERSION = '0.6';
+our $VERSION = '0.7';
 
 __PACKAGE__->attr(conf => sub { +{} });
 
 sub register {
 	my ($plugin, $app, $conf) = @_;
 	
+	# default values
+	$conf->{from    } ||= FROM;
+	$conf->{charset } ||= CHARSET;
+	$conf->{encoding} ||= ENCODING;
+	
 	$plugin->conf( $conf ) if $conf;
 	
 	$app->renderer->add_helper(
@@ -35,11 +42,18 @@ sub register {
 			}
 			
 			# hidden data and subject
-			$args->{mail}->{Data   } ||= $self->helper('render_mail');
+			
+			my @stash =
+				map  { $_ => $args->{$_} }
+				grep { !/^(to|from|cc|bcc|subject|data|test|mail|attach|headers|attr|charset|mimeword|nomailer)$/ }
+				keys %$args
+			;
+			
+			$args->{mail}->{Data   } ||= $self->helper('render_mail', @stash);
 			$args->{mail}->{Subject} ||= $self->stash ('subject');
 			
 			my $msg  = $plugin->build( %$args );
-			my $test = { @_ }->{test} || TEST;
+			my $test = $args->{test} || TEST;
 			$msg->send( $conf->{'how'}, @{$conf->{'howargs'}||[]} ) unless $test;
 			
 			return $msg->as_string;
@@ -63,7 +77,7 @@ sub build {
 	my $p    = { @_ };
 	
 	my $mail     = $p->{mail};
-	my $charset  = $p->{charset } || $conf->{charset } || CHARSET;
+	my $charset  = $p->{charset } || $conf->{charset };
 	my $encoding = $p->{encoding} || $conf->{encoding};
 	my $encode   = $encoding eq 'base64' ? 'B' : 'Q';
 	my $mimeword = defined $p->{mimeword} ? $p->{mimeword} : !$encoding ? 0 : 1;
@@ -81,8 +95,8 @@ sub build {
 	if ($mimeword) {
 		$_ = MIME::EncWords::encode_mimeword($_, $encode, $charset) for grep { _enc($_); 1 } $mail->{Subject};
 		
-		for ( grep { $_ } @$mail{ qw(From To Cc Bcc) } ) {
-			$_ = join ",\n",
+		for (grep { $mail->{$_} } qw(From To Cc Bcc)) {
+			$mail->{$_} = join ",\n",
 				grep {
 					_enc($_);
 					{
@@ -98,7 +112,7 @@ sub build {
 					}
 					1;
 				}
-				split /\s*,\s*/
+				split /\s*,\s*/, $mail->{$_}
 			;
 		}
 	}
@@ -150,7 +164,10 @@ Mojolicious::Plugin::Mail - Mojolicious Plugin for send mail
 
 =head1 SYNOPSIS
 
-  # Mojolicious
+   # Mojolicious::Lite
+   plugin 'mail';
+
+  # Mojolicious with config
   $self->plugin(mail => {
     from     => 'sharifulin@gmail.com',
     encoding => 'base64',
@@ -158,18 +175,7 @@ Mojolicious::Plugin::Mail - Mojolicious Plugin for send mail
     howargs  => [ '/usr/sbin/sendmail -t' ],
   });
 
-  # Mojolicious::Lite
-  plugin mail => { ... }; # second param is conf 
-
-
   # in controller
-  $self->helper('mail',
-    to      => 'sharifulin@gmail.com',
-    subject => 'Test'm
-    data    => 'use Perl or die;',
-  );
-
-  # in controller (new version of Mojolicious)
   $self->mail(
     to      => 'sharifulin@gmail.com',
     subject => 'Test',
@@ -177,7 +183,7 @@ Mojolicious::Plugin::Mail - Mojolicious Plugin for send mail
   );
 
   # in controller, using render
-  $self->mail(to => 'sharifulin@gmail.com');
+  $self->mail(to => 'sharifulin@gmail.com', template => 'controller/action', format => 'mail');
 
   # template: controller/action.mail.ep
   % stash subject => 'Test';
@@ -195,7 +201,7 @@ L<Mojolicious::Plugin::Mail> contains two helpers: I<mail> and I<render_mail>.
 =head2 C<mail>
 
   # simple interface
-  $self->helper('mail',
+  $self->mail(
       to      => 'sharifulin@gmail.com',
       from    => 'sharifulin@gmail.com',
       
@@ -207,7 +213,7 @@ L<Mojolicious::Plugin::Mail> contains two helpers: I<mail> and I<render_mail>.
   );
 
   # interface as MIME::Lite
-  $self->helper('mail',
+  $self->mail(
       # test mode
       test   => 1,
       
@@ -307,12 +313,10 @@ If no data, call I<render_mail> helper with all stash parameters.
 
 =head2 C<render_mail>
 
-  my $data = $self->helper('render_mail', 'user/signup');
-  # or
-  my $data = $self->render_mail('user/signup'); # new version of Mojolicious
+  my $data = $self->render_mail('user/signup');
 
   # or use stash params
-  my $data = $self->helper('render_mail', template => 'user/signup', user => $user);
+  my $data = $self->render_mail(template => 'user/signup', user => $user);
 
 Render mail template and return data, mail template format is I<mail>, i.e. I<user/signup.mail.ep>.
 
@@ -332,15 +336,16 @@ Keys of conf:
 
 =item * from
 
-Default from address
+From address, default value is I<test-mail-plugin@mojolicio.us>.
 
 =item * encoding 
 
-Default encoding of Subject and any Data, value is MIME::Lite content transfer encoding L<http://search.cpan.org/~rjbs/MIME-Lite-3.027/lib/MIME/Lite.pm#Content_transfer_encodings>
+Encoding of Subject and any Data, value is MIME::Lite content transfer encoding L<http://search.cpan.org/~rjbs/MIME-Lite-3.027/lib/MIME/Lite.pm#Content_transfer_encodings>
+Default value is I<base64>.
 
 =item * charset
 
-Default charset of Subject and any Data, default value is I<UTF-8>
+Default charset of Subject and any Data, default value is I<UTF-8>.
 
 =item * type
 
@@ -396,14 +401,16 @@ L<Mojolicious::Plugin::Mail> has test mode, no send mail.
   BEGIN { $ENV{MOJO_MAIL_TEST} = 1 };
 
   # or only once
-  $self->helper('mail',
+  $self->mail(
     test => 1,
-    mail => { ... },
+    to   => '...',
   );
 
 =head1 EXAMPLES
 
-Simple interface for send mail using new version of Mojolicious:
+The Mojolicious::Lite example you can see in I<example/test.pl>.
+
+Simple interface for send mail:
 
   get '/simple' => sub {
     my $self = shift;
@@ -420,7 +427,7 @@ Simple send mail:
   get '/simple' => sub {
     my $self = shift;
     
-    $self->helper('mail',
+    $self->mail(
       mail => {
         To      => 'sharifulin@gmail.com',
         Subject => 'Тест письмо',
@@ -434,7 +441,7 @@ Simple send mail with test mode:
   get '/simple2' => sub {
     my $self = shift;
     
-    my $mail = $self->helper('mail',
+    my $mail = $self->mail(
       test => 1,
       mail => {
         To      => '"Анатолий Шарифулин" sharifulin@gmail.com',
@@ -454,7 +461,7 @@ Mail with binary attachcment, charset is windows-1251, mimewords off and mail ha
   get '/attach' => sub {
     my $self = shift;
     
-    my $mail = $self->helper('mail',
+    my $mail = $self->mail(
       charset  => 'windows-1251',
       mimeword => 0,
 
@@ -483,7 +490,7 @@ Multipart mixed mail:
   get '/multi' => sub {
     my $self = shift;
     
-    $self->helper('mail',
+    $self->mail(
       mail => {
         To      => 'sharifulin@gmail.com',
         Subject => 'Мульти',
@@ -524,8 +531,8 @@ Mail with render data and subject from stash param:
   get '/render' => sub {
     my $self = shift;
 
-    my $data = $self->helper('render_mail', 'render');
-    $self->helper('mail',
+    my $data = $self->render_mail('render');
+    $self->mail(
       mail => {
         To      => 'sharifulin@gmail.com',
         Subject => $self->stash('subject'),
